@@ -2,7 +2,7 @@
 // File: init.cpp
 // Contents: initialization routines for the extension
 //
-// Microsoft Drivers 5.6 for PHP for SQL Server
+// Microsoft Drivers 5.8 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -219,7 +219,7 @@ zend_function_entry sqlsrv_functions[] = {
     PHP_FE( sqlsrv_client_info, sqlsrv_client_info_arginfo )
     PHP_FE( sqlsrv_server_info, sqlsrv_server_info_arginfo )
     PHP_FE( sqlsrv_cancel, sqlsrv_cancel_arginfo )
-    PHP_FE( sqlsrv_free_stmt, sqlsrv_close_arginfo )
+    PHP_FE( sqlsrv_free_stmt, sqlsrv_free_stmt_arginfo )
     PHP_FE( sqlsrv_field_metadata, sqlsrv_field_metadata_arginfo )
     PHP_FE( sqlsrv_send_stream_data, sqlsrv_send_stream_data_arginfo ) 
     PHP_FE( SQLSRV_SQLTYPE_BINARY, sqlsrv_sqltype_size_arginfo )
@@ -654,6 +654,25 @@ PHP_RINIT_FUNCTION(sqlsrv)
     SQLSRV_G( log_subsystems ) = INI_INT( subsystems );
     SQLSRV_G( buffered_query_limit ) = INI_INT( buffered_limit );
 
+#ifndef _WIN32
+    char set_locale_info[] = INI_PREFIX INI_SET_LOCALE_INFO;
+    SQLSRV_G(set_locale_info) = INI_INT(set_locale_info);
+
+    // if necessary, set locale from the environment for ODBC, which MUST be done before any connection
+    int set_locale = SQLSRV_G(set_locale_info);
+    if (set_locale == 2) {
+        setlocale(LC_ALL, "");
+    }
+    else if (set_locale == 1) {
+        setlocale(LC_CTYPE, "");
+    }
+    else {
+        // Do nothing
+    }
+
+    LOG(SEV_NOTICE, INI_PREFIX INI_SET_LOCALE_INFO " = %1!d!", set_locale);
+#endif
+
     LOG( SEV_NOTICE, INI_PREFIX INI_WARNINGS_RETURN_AS_ERRORS " = %1!s!", SQLSRV_G( warnings_return_as_errors ) ? "On" : "Off");
     LOG( SEV_NOTICE, INI_PREFIX INI_LOG_SEVERITY " = %1!d!", SQLSRV_G( log_severity ));
     LOG( SEV_NOTICE, INI_PREFIX INI_LOG_SUBSYSTEMS " = %1!d!", SQLSRV_G( log_subsystems ));
