@@ -3,7 +3,7 @@
 //
 // Contents: Core routines that use connection handles shared between sqlsrv and pdo_sqlsrv
 //
-// Microsoft Drivers 5.6 for PHP for SQL Server
+// Microsoft Drivers 5.8 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -386,7 +386,7 @@ SQLRETURN core_odbc_connect( _Inout_ sqlsrv_conn* conn, _Inout_ std::string& con
 
     // We only support UTF-8 encoding for connection string.
     // Convert our UTF-8 connection string to UTF-16 before connecting with SQLDriverConnnectW
-    wconn_string = utf16_string_from_mbcs_string( SQLSRV_ENCODING_UTF8, conn_str.c_str(), static_cast<unsigned int>( conn_str.length() ), &wconn_len );
+    wconn_string = utf16_string_from_mbcs_string( SQLSRV_ENCODING_UTF8, conn_str.c_str(), static_cast<unsigned int>( conn_str.length() ), &wconn_len, true );
 
     CHECK_CUSTOM_ERROR( wconn_string == 0, conn, SQLSRV_ERROR_CONNECT_STRING_ENCODING_TRANSLATE, get_last_error_message())
     {
@@ -702,22 +702,32 @@ void core_sqlsrv_get_client_info( _Inout_ sqlsrv_conn* conn, _Out_ zval *client_
 
 bool core_is_conn_opt_value_escaped( _Inout_ const char* value, _Inout_ size_t value_len )
 {
-    // if the value is already quoted, then only analyse the part inside the quotes and return it as
-    // unquoted since we quote it when adding it to the connection string.
-    if( value_len > 0 && value[0] == '{' && value[value_len - 1] == '}' ) {
-        ++value;
+    if (value_len == 0) {
+        return true;
+    }
+
+    if (value_len == 1) {
+        return (value[0] != '}');
+    }
+
+    const char *pstr = value;
+    if (value_len > 0 && value[0] == '{' && value[value_len - 1] == '}') {
+        pstr = ++value;
         value_len -= 2;
     }
-    // check to make sure that all right braces are escaped
+
+    const char *pch = strchr(pstr, '}');
     size_t i = 0;
-    while( ( value[i] != '}' || ( value[i] == '}' && value[i+1] == '}' )) && i < value_len ) {
-        // skip both braces
-        if( value[i] == '}' )
-            ++i;
-        ++i;
-    }
-    if( i < value_len && value[i] == '}' ) {
-        return false;
+
+    while (pch != NULL && i < value_len) {
+        i = pch - pstr + 1;
+
+        if (i == value_len || (i < value_len && pstr[i] != '}')) {
+            return false;
+        }
+
+        i++;    // skip the brace
+        pch = strchr(pch + 2, '}'); // continue searching
     }
 
     return true;
@@ -773,7 +783,7 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
 
     try {
         // Since connection options access token and authentication cannot coexist, check if both of them are used.
-        // If access token is specified, check UID andPWD as well. 
+        // If access token is specified, check UID andPWD as well.
         // No need to check the keyword Trusted_Connectionbecause it is not among the acceptable options for SQLSRV drivers
         if (zend_hash_index_exists(options, SQLSRV_CONN_OPTION_ACCESS_TOKEN)) {
             bool invalidOptions = false;
@@ -791,7 +801,7 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
             access_token_used = true;
         }
 
-        // Check if Authentication is ActiveDirectoryMSI 
+        // Check if Authentication is ActiveDirectoryMSI
         // https://docs.microsoft.com/en-ca/azure/active-directory/managed-identities-azure-resources/overview
         bool activeDirectoryMSI = false;
         if (authentication_option_used) {
@@ -803,7 +813,7 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
             if (!stricmp(option, AzureADOptions::AZURE_AUTH_AD_MSI)) {
                 activeDirectoryMSI = true;
 
-                // There are two types of managed identities: 
+                // There are two types of managed identities:
                 // (1) A system-assigned managed identity: UID must be NULL
                 // (2) A user-assigned managed identity: UID defined but must not be an empty string
                 // In both cases, PWD must be NULL
@@ -822,11 +832,11 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
                 }
             }
         }
-       
+
         // Add the server name
         common_conn_str_append_func( ODBCConnOptions::SERVER, server, strnlen_s( server ), connection_string TSRMLS_CC );
 
-        // If uid is not present then we use trusted connection -- but not when access token or ActiveDirectoryMSI is used, 
+        // If uid is not present then we use trusted connection -- but not when access token or ActiveDirectoryMSI is used,
         // because they are incompatible
         if (!access_token_used && !activeDirectoryMSI) {
             if (uid == NULL || strnlen_s(uid) == 0) {
@@ -1143,9 +1153,12 @@ void column_encryption_set_func::func( _In_ connection_option const* option, _In
     convert_to_string( value );
     const char* value_str = Z_STRVAL_P( value );
 
-    // Column Encryption is disabled by default unless it is explicitly 'Enabled'
+    // Column Encryption is disabled by default, but if it is present and not
+    // explicitly set to disabled or enabled, the ODBC driver will assume the
+    // user is providing an attestation protocol and URL for enclave support.
+    // For our purposes we need only set ce_option.enabled to true if not disabled.
     conn->ce_option.enabled = false;
-    if ( !stricmp(value_str, "enabled" )) {
+    if ( stricmp(value_str, "disabled" )) {
         conn->ce_option.enabled = true;
     }
 
@@ -1190,7 +1203,7 @@ void ce_akv_str_set_func::func(_In_ connection_option const* option, _In_ zval*
         char *pValue = static_cast<char*>(sqlsrv_malloc(value_len + 1));
         memcpy_s(pValue, value_len + 1, value_str, value_len);
         pValue[value_len] = '\0';   // this makes sure there will be no trailing garbage
-        
+
         // This will free the existing memory block before assigning the new pointer -- the user might set the value(s) more than once
         if (option->conn_option_key == SQLSRV_CONN_OPTION_KEYSTORE_PRINCIPAL_ID) {
             conn->ce_option.akv_id = pValue;
@@ -1252,10 +1265,10 @@ void access_token_set_func::func( _In_ connection_option const* option, _In_ zva
     }
 
     const char* value_str = Z_STRVAL_P( value );
-    
-    // The SQL_COPT_SS_ACCESS_TOKEN pre-connection attribute allows the use of an access token (in the format extracted from 
-    // an OAuth JSON response), obtained from Azure AD for authentication instead of username and password, and also 
-    // bypasses the negotiation and obtaining of an access token by the driver. To use an access token, set the 
+
+    // The SQL_COPT_SS_ACCESS_TOKEN pre-connection attribute allows the use of an access token (in the format extracted from
+    // an OAuth JSON response), obtained from Azure AD for authentication instead of username and password, and also
+    // bypasses the negotiation and obtaining of an access token by the driver. To use an access token, set the
     // SQL_COPT_SS_ACCESS_TOKEN connection attribute to a pointer to an ACCESSTOKEN structure
     //
     //  typedef struct AccessToken
@@ -1266,30 +1279,30 @@ void access_token_set_func::func( _In_ connection_option const* option, _In_ zva
     //
     // NOTE: The ODBC Driver version 13.1 only supports this authentication on Windows.
     //
-    // A valid access token byte string must be expanded so that each byte is followed by a 0 padding byte, 
+    // A valid access token byte string must be expanded so that each byte is followed by a 0 padding byte,
     // similar to a UCS-2 string containing only ASCII characters
     //
     // See https://docs.microsoft.com/sql/connect/odbc/using-azure-active-directory#authenticating-with-an-access-token
 
     size_t dataSize = 2 * value_len;
-    
-    sqlsrv_malloc_auto_ptr<ACCESSTOKEN> accToken;   
+
+    sqlsrv_malloc_auto_ptr<ACCESSTOKEN> accToken;
     accToken = reinterpret_cast<ACCESSTOKEN*>(sqlsrv_malloc(sizeof(ACCESSTOKEN) + dataSize));
 
     ACCESSTOKEN *pAccToken = accToken.get();
     SQLSRV_ASSERT(pAccToken != NULL, "Something went wrong when trying to allocate memory for the access token.");
 
     pAccToken->dataSize = dataSize;
-    
+
     // Expand access token with padding bytes
     for (size_t i = 0, j = 0; i < dataSize; i += 2, j++) {
         pAccToken->data[i] = value_str[j];
         pAccToken->data[i+1] = 0;
     }
-    
+
     core::SQLSetConnectAttr(conn, SQL_COPT_SS_ACCESS_TOKEN, reinterpret_cast<SQLPOINTER>(pAccToken), SQL_IS_POINTER);
-    
-    // Save the pointer because SQLDriverConnect() will use it to make connection to the server 
+
+    // Save the pointer because SQLDriverConnect() will use it to make connection to the server
     conn->azure_ad_access_token = pAccToken;
     accToken.transferred();
 }
