@@ -3,7 +3,7 @@
 //
 // Contents: Result sets
 //
-// Microsoft Drivers 5.6 for PHP for SQL Server
+// Microsoft Drivers 5.8 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -243,14 +243,12 @@ std::string getUTF8StringFromString( _In_z_ const SQLWCHAR* source )
 {
     // convert to regular character string first
     char c_str[4] = "";
-    mbstate_t mbs;
 
     SQLLEN i = 0;
     std::string str;
     while ( source[i] )
     {        
         memset( c_str, 0, sizeof( c_str ) );        
-        DWORD rc;    
         int cch = 0;
         errno_t err = mplat_wctomb_s( &cch, c_str, sizeof( c_str ), source[i++] );
         if ( cch > 0 && err == ERROR_SUCCESS )
@@ -510,6 +508,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
                 break;
             case SQL_CHAR:
             case SQL_VARCHAR:
+            case SQL_SS_VARIANT:
                 if ( meta[i].length == sqlsrv_buffered_result_set::meta_data::SIZE_UNKNOWN ) {
                     offset += sizeof( void* );
                 }
@@ -612,6 +611,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
                 
             case SQL_CHAR:
             case SQL_VARCHAR:
+            case SQL_SS_VARIANT:
             case SQL_LONGVARCHAR:
                 // If encoding is set to UTF-8, the following types are not necessarily column size.
                 // We need to call SQLGetData with c_type SQL_C_WCHAR and set the size accordingly. 
