@@ -5,7 +5,7 @@
 //           Must be included in one c/cpp file per binary
 //           A build error will occur if this inclusion policy is not followed
 //
-// Microsoft Drivers 5.6 for PHP for SQL Server
+// Microsoft Drivers 5.8 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -280,9 +280,23 @@ bool EncodingConverter::Initialize()
 using namespace std;
 
 SystemLocale::SystemLocale( const char * localeName )
-    :   m_pLocale( new std::locale(localeName) )
-    , m_uAnsiCP(CP_UTF8)
+    : m_uAnsiCP(CP_UTF8)
+    , m_pLocale(NULL)
 {
+    const char* DEFAULT_LOCALE = "en_US.UTF-8";
+
+    try {
+        m_pLocale = new std::locale(localeName);
+    }
+    catch(const std::exception& e) {
+        localeName = DEFAULT_LOCALE;
+    }
+    
+    if(!m_pLocale) {
+        m_pLocale = new std::locale(localeName);
+    }
+
+    // Mapping from locale charset to codepage
     struct LocaleCP
     {
         const char* localeName;
@@ -331,8 +345,7 @@ const SystemLocale & SystemLocale::Singleton()
 #if !defined(__GNUC__) || defined(NO_THREADSAFE_STATICS)
     #error "Relying on GCC's threadsafe initialization of local statics."
 #endif
-    // get locale from environment and set as default
-    static const SystemLocale s_Default(setlocale(LC_ALL, NULL));
+    static const SystemLocale s_Default(setlocale(LC_CTYPE, NULL));
     return s_Default;
 }
 
